import document from 'arg.js/src/document';
import cuit from 'arg.js/src/cuit';
import areaCodes from "./data/areaCodes";

import {
    size, inRange, parseInt, isEqual, isNaN, find
} from 'lodash';

// eslint-disable-next-line max-len
const emailRegex = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
const numberRegex = /[0-9]+/;
const dateRegex = /^\d{4}\-(0[1-9]|1[012])\-(0[1-9]|[12][0-9]|3[01])$/;
const arPhone = /(^([+])+([5])+([4])+([9]))/;

function validateAreaCode(input) {
    return (find(areaCodes,  function (o) {
        return (o.area_code == input)}) !== undefined)}

function getCity(input) {
    return (find(areaCodes,  function (o) {
        return (o.area_code == input)})).city}

function getAreaCode(input){
    //TODO Make this trough a loop
    let area = input.slice(4,6);
        if (validateAreaCode(area)) {
            return area
        }
        else {
            area = input.slice(4,7)
            if (validateAreaCode(area)) {
                return area
            }
            else {
                area = input.slice(4,8)
                if (validateAreaCode(area)) {
                    return area
                }
                else {return 0}
                }
            }
}

export default class ValidatorService {
    static validateText(input, max = 50, min = 2) {
        return inRange(size(input), min, max + 1);
    }

    static validateSelectMultiple(input) {
        return size(input) > 0;
    }

    static validateNumber(input) {
        if (input === '.') {
            return true;
        }
        return numberRegex.test(input);
    }

    static validateDate(input) {
        return dateRegex.test(input)
    }

    static validateEmail(email) {
        return emailRegex.test(email);
    }

    static validateDocument(input) {
        return input && !isNaN(parseInt(input)) && document.isValidDni(input);
    }

    static validateCuil(cuil) {
        return cuit.isValid(cuil);
    }

    static validateCompare(input, compareInput, max = 50, min = 2) {
        return inRange(size(input), min, max) && isEqual(input, compareInput);
    }

    static validatePhone(input) {


        if (size(input) == 14) {
            if (!arPhone.test(input)) {
                return (
                    {
                        error: {status: 'invalid', message: ('Formato invalido - Verifique Prefijo Internacional')}
                    })
            }
            const area = getAreaCode(input)
            if (area!==0) {
                return (
                    {
                    error: {status: 'valid', message: ('Formato valido' + ' Codigo de Area: ' + getCity(area))}
                    })
                }
            else
                {
                    return (
                        {
                            error: {status: 'invalid', message: ('Formato invalido' + ' Codigo de Area: Invalido')}
                        })
                }

            } else {
                return (
                    {
                        error: {status: 'invalid', message: ('Formato invalido ')}
                    })

            }
        }
}

